aboutsummaryrefslogtreecommitdiff
path: root/mod
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2024-10-22 13:20:11 +0200
committerKaren Arutyunov <karen@codesynthesis.com>2024-10-23 09:09:37 +0200
commit15159b41c82233b709513f689b7797ff50809562 (patch)
tree751b65a4c8d0185d0d98d04d69a6ae05c6608444 /mod
parentf35d90ecfd55a354e6ea2386146111a8cef10da9 (diff)
Adjust terminology in ci-common header
Diffstat (limited to 'mod')
-rw-r--r--mod/ci-common.hxx15
1 files changed, 6 insertions, 9 deletions
diff --git a/mod/ci-common.hxx b/mod/ci-common.hxx
index d01e251..cc432c4 100644
--- a/mod/ci-common.hxx
+++ b/mod/ci-common.hxx
@@ -37,19 +37,19 @@ namespace brep
optional<brep::version> version;
};
// Note that the inability to generate the reference is an internal
// error. Thus, it is not optional.
//
struct start_result
{
uint16_t status;
string message;
- string reference;
+ string tenant_id;
vector<pair<string, string>> custom_result;
};
- // In the optional service information, if id is empty, then the generated
- // reference is used instead.
+ // In the optional tenant service information, if service id is empty,
+ // then the generated tenant id is used instead.
//
optional<start_result>
start (const basic_mark& error,
@@ -65,7 +65,7 @@ namespace brep
const vector<pair<string, string>>& custom_request = {},
const vector<pair<string, string>>& overrides = {}) const;
// Create an unloaded CI request returning start_result::reference on
// success and nullopt on an internal error. Such a request is not started
// until loaded with the load() function below. Configure the time
// interval between the build_unloaded() notifications for the being
@@ -79,7 +79,7 @@ namespace brep
// below) and a new tenant with the same type/id created. In both these
// modes (ignore and replace), the second half of the returned pair
// indicates whether there was a duplicate. If there were, then for the
- // ignore mode the returned reference corresponds to the old tenant and
+ // ignore mode the returned tenant id corresponds to the old tenant and
// for the replace mode -- to the new tenant.
//
// The replace_archived mode is a variant of replace that replaces if the
@@ -144,9 +144,6 @@ namespace brep
// is no tenant for the specified tenant id. Note that the reason argument
// is only used for tracing.
//
- // @@@ Is tenant id here and reference above the same thing? Maybe use
- // "tenant id" and "service id" terminology throughout?
- //
// Similarly to above, this function archives the tenant, unless the
// tenant is unloaded, in which case it is dropped (@@@ TODO). Note,
// however, that this version does not touch the service state (use the
@@ -37,19 +37,19 @@ namespace brep
optional<brep::version> version;
};
- // Note that the inability to generate the reference is an internal
+ // Note that the inability to generate the tenant id is an internal
// error. Thus, it is not optional.
//
@@ -65,7 +65,7 @@ namespace brep
const vector<pair<string, string>>& custom_request = {},
const vector<pair<string, string>>& overrides = {}) const;
- // Create an unloaded CI request returning start_result::reference on
+ // Create an unloaded CI request returning start_result::tenant_id on
// success and nullopt on an internal error. Such a request is not started
// until loaded with the load() function below. Configure the time